@@ -221,6 +221,9 @@ sub merge_config {
                 : '.';
     }
 
+    # inherit the 'copy_skip' attribute if not set in the child
+    $self->{copy_skip} ||= $parent_o->{copy_skip} || [];
+
 }
 
 
@@ -612,8 +615,6 @@ META: to be completed (see SYNOPSIS meanwhile)
 
 =back
 
-=back
-
 =head1 CONFIGURATION FILE
 
 Each DocSet has its own configuration file.
@@ -1031,8 +1032,6 @@ HTML, so the parser will be able to extract the body. Of course these
 can be POD or other formats as well. But all is taken from these files
 are their bodies, so the title and other meta-data are ignored.
 
-=back
-
 =head1 AUTHORS
 
 Stas Bekman E<lt>stas (at) stason.orgE<gt>
